<?php 

/**
 * Build theme metaboxes
 * Uses the cmb metaboxes class found in the ebor framework plugin
 * More details here: https://github.com/WebDevStudios/Custom-Metaboxes-and-Fields-for-WordPress
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_custom_metaboxes') )){
	function ebor_custom_metaboxes( $meta_boxes ) {
		
		/**
		 * Setup variables
		 */
		$prefix = '_ebor_';
		$social_options = ebor_get_social_icons();
		$header_options = ebor_get_header_layouts();
		
		$header_overrides['none'] = 'Do Not Override Header Option On This Page';
		foreach( $header_options as $key => $value ){
			$header_overrides[$key] = 'Override Header: ' . $value; 	
		}
		
		/**
		 * Portfolio Settings Metabox
		 */
		$meta_boxes[] = array(
			'id' => 'portfolio_meta_metabox',
			'title' => __('Additional Portfolio Settings', 'kwoon'),
			'object_types' => array('portfolio'),
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true,
			'fields' => array(
				array(
					'name' => 'Masonry Gallery Layout',
					'description' => 'Using the "Masonry" portfolio type? Set how this items featured image should be sized.',
					'id' => $prefix . 'masonry_layout',
					'type' => 'select',
					'options' => array(
						array('name' => 'Normal Width, Normal Height (285x190px)', 'value' => 'normal'),
						array('name' => 'Double Width, Normal Height (580x190px)', 'value' => 'width2'),
						array('name' => 'Normal Width, Double Height (285x390px)', 'value' => 'height2'),
						array('name' => 'Double Width, Double Height (580x390px)', 'value' => 'width2 height2'),
					),
					'std' => 'normal'
				),
				array(
					'name' => 'Post Meta Layout',
					'id' => $prefix . 'meta_layout',
					'type' => 'select',
					'options' => array(
						array('name' => 'Content Left, Meta Right', 'value' => 'meta-right'),
						array('name' => 'Content Right, Meta Left', 'value' => 'meta-left'),
						array('name' => 'No Meta', 'value' => 'meta-none'),
					),
					'std' => 'meta-right'
				),
				array(
					'name' => __('Project Date', 'kwoon'),
					'desc' => __("(Optional) Add the Date this Project Took Place?", 'kwoon'),
					'id'   => $prefix . 'the_client_date',
					'type' => 'text_date',
				),
				array(
				    'id'          => $prefix . 'meta_repeat_group',
				    'type'        => 'group',
				    'description' => __( 'Additional Meta Titles & Descriptions', 'kwoon' ),
				    'options'     => array(
				        'add_button'    => __( 'Add Another Entry', 'kwoon' ),
				        'remove_button' => __( 'Remove Entry', 'kwoon' ),
				        'sortable'      => true, // beta
				    ),
				    'fields'      => array(
						array(
							'name' => __('Additional Item Title', 'kwoon'),
							'desc' => __("Title of your Additional Meta", 'kwoon'),
							'id'   => $prefix . 'the_additional_title',
							'type' => 'text'
						),
						array(
							'name' => __('Additional Item Detail', 'kwoon'),
							'desc' => __("Detail of your Additional Meta", 'kwoon'),
							'id'   => $prefix . 'the_additional_detail',
							'type' => 'text'
						),
				    ),
				),
			)
		);
		
		/**
		 * Portfolio Items Gallery Metabox
		 */
		$meta_boxes[] = array(
			'id' => 'portfolio_metabox',
			'title' => __('Photo Gallery Settings', 'kwoon'),
			'object_types' => array('portfolio'),
			'context' => 'side',
			'priority' => 'low',
			'show_names' => true,
			'fields' => array(
				array(
					'name' => 'Post Layout',
					'id' => $prefix . 'gallery_layout',
					'type' => 'select',
					'options' => array(
						array('name' => 'Boxed Gallery Below Content', 'value' => 'bottom-boxed'),
						array('name' => 'Fullwidth Gallery Below Content', 'value' => 'bottom-full'),
						array('name' => 'Boxed Gallery Below Content (With Sidebar)', 'value' => 'bottom-sidebar'),
						array('name' => 'Boxed Gallery Above Content', 'value' => 'top-boxed'),
						array('name' => 'Fullwidth Gallery Above Content', 'value' => 'top-full'),
						array('name' => 'Boxed Gallery Above Content (With Sidebar)', 'value' => 'top-sidebar'),
						array('name' => 'Gallery Left, Content Right', 'value' => 'half-left'),
						array('name' => 'Gallery Right, Content Left', 'value' => 'half-right'),
					),
					'std' => 'bottom-boxed'
				),
				array(
					'name' => 'Post Gallery Type',
					'id' => $prefix . 'gallery_type',
					'type' => 'select',
					'options' => array(
						array('name' => 'Carousel', 'value' => 'basic-carousel'),
						array('name' => 'Slider', 'value' => 'basic-slider'),
						array('name' => 'Image Feed', 'value' => 'basic-gallery'),
						array('name' => 'Masonry Gallery', 'value' => 'masonry-gallery'),
						array('name' => 'Video', 'value' => 'video')
					),
					'std' => 'basic-carousel'
				),
				array(
					'name' => 'Upload Gallery Images',
					'desc' => 'Min Height 550px, Max 1400px, Drag & Drop to Reorder',
					'id' => $prefix . 'gallery_images',
					'type' => 'file_list',
				),
				array(
					'name' => 'oEmbed',
					'desc' => 'Enter a youtube, twitter, or instagram URL. Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.',
					'id'   => $prefix . 'the_oembed',
					'type' => 'oembed',
				),
				array(
					'name' => 'Show Gallery Captions?',
					'id' => $prefix . 'gallery_captions',
					'type' => 'select',
					'options' => array(
						'no' => 'No',
						'yes' => 'Yes'
					),
					'std' => 'no'
				),
			)
		);
		
		$meta_boxes[] = array(
			'id' => 'page_title_metabox',
			'title' => __('Page Title Options', 'kwoon'),
			'object_types' => array('page', 'post', 'team', 'portfolio'), // post type
			'context' => 'side',
			'priority' => 'low',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => 'Page Title Layout',
					'desc' => 'How would you like the page title to appear for this page?',
					'id' => $prefix . 'page_title_layout',
					'type' => 'select',
					'options' => array(
						'light' => 'Light Background',
						'dark' => 'Dark Background',
						'image' => 'Image Background (Uses featured image)',
						'none' => 'No Page Title'
					)
				),
			)
		);
		
		/**
		 * Social Icons for Team Members
		 */
		$meta_boxes[] = array(
			'id' => 'team_social_metabox',
			'title' => __('Team Member Details', 'kwoon'),
			'object_types' => array('team'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => __('Job Title', 'kwoon'),
					'desc' => '(Optional) Enter a Job Title for this Team Member',
					'id'   => $prefix . 'the_job_title',
					'type' => 'text',
				),
				array(
				    'id'          => $prefix . 'team_social_icons',
				    'type'        => 'group',
				    'options'     => array(
				        'add_button'    => __( 'Add Another Icon', 'kwoon' ),
				        'remove_button' => __( 'Remove Icon', 'kwoon' ),
				        'sortable'      => true
				    ),
				    'fields' => array(
						array(
							'name' => 'Social Icon',
							'desc' => 'What icon would you like for this team members first social profile?',
							'id' => $prefix . 'social_icon',
							'type' => 'select',
							'options' => $social_options
						),
						array(
							'name' => __('URL for Social Icon', 'kwoon'),
							'desc' => __("Enter the URL for Social Icon 1 e.g www.google.com", 'kwoon'),
							'id'   => $prefix . 'social_icon_url',
							'type' => 'text_url',
						),
				    ),
				),
			)
		);
		
		/**
		 * Testimonial Options
		 */
		$meta_boxes[] = array(
			'id' => 'testimonial_metabox',
			'title' => __('Testimonial Details', 'kwoon'),
			'object_types' => array('testimonial'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => __('Job Title', 'kwoon'),
					'desc' => '(Optional) Enter a Job Title for this testimonial',
					'id'   => $prefix . 'the_job_title',
					'type' => 'text',
				),
			)
		);
		
		/**
		 * Client options
		 */
		$meta_boxes[] = array(
			'id' => 'clients_metabox',
			'title' => __('Client URL', 'kwoon'),
			'object_types' => array('client'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => __('URL for this client (optional)', 'kwoon'),
					'desc' => __("Enter a URL for this client.", 'kwoon'),
					'id'   => $prefix . 'client_url',
					'type' => 'text',
				),
			),
		);
		
		/**
		 * testimonial options
		 */
		$meta_boxes[] = array(
			'id' => 'testimonial_metabox',
			'title' => __('Testimonial URL', 'kwoon'),
			'object_types' => array('testimonial'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => __('URL for this testimonial (optional)', 'kwoon'),
					'desc' => __("Enter a URL for this testimonial.", 'kwoon'),
					'id'   => $prefix . 'testimonial_url',
					'type' => 'text',
				),
			),
		);
		
		/**
		 * Social Icons for Users
		 */
		$meta_boxes[] = array(
			'id' => 'social_metabox',
			'title' => __('Social Icons: Click To Add More', 'kwoon'),
			'object_types' => array('user'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
				    'id'          => $prefix . 'user_social_icons',
				    'type'        => 'group',
				    'options'     => array(
				        'add_button'    => __( 'Add Another Icon', 'kwoon' ),
				        'remove_button' => __( 'Remove Icon', 'kwoon' ),
				        'sortable'      => true
				    ),
				    'fields' => array(
						array(
							'name' => 'Social Icon',
							'desc' => 'What icon would you like for this team members first social profile?',
							'id' => $prefix . 'social_icon',
							'type' => 'select',
							'options' => $social_options
						),
						array(
							'name' => __('URL for Social Icon', 'kwoon'),
							'desc' => __("Enter the URL for Social Icon 1 e.g www.google.com", 'kwoon'),
							'id'   => $prefix . 'social_icon_url',
							'type' => 'text',
						),
				    ),
				),
			)
		);
		
		$meta_boxes[] = array(
			'id' => 'post_layout_metabox',
			'title' => __('Post Layout Options', 'kwoon'),
			'object_types' => array('post'), // post type
			'context' => 'normal',
			'priority' => 'high',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name' => 'Post Layout',
					'desc' => 'How would you like the layout for this post?',
					'id' => $prefix . 'post_layout',
					'type' => 'select',
					'options' => array(
						'boxed' => 'Boxed Elements',
						'boxed-no-sidebar' => 'Boxed Elements, No Sidebar',
						'unboxed' => 'Unboxed Elements',
						'unboxed-no-sidebar' => 'Unboxed Elements, No Sidebar',
					),
					'std' => 'boxed'
				),
				array(
					'name' => 'Gallery Post Format Images',
					'desc' => 'Drag & Drop to Reorder',
					'id' => $prefix . 'gallery_images',
					'type' => 'file_list',
				),
				array(
				    'id'          => $prefix . 'videos',
				    'type'        => 'group',
				    'options'     => array(
				        'add_button'    => __( 'Add Another oEmbed', 'kwoon' ),
				        'remove_button' => __( 'Remove oEmbed', 'kwoon' ),
				        'sortable'      => true
				    ),
				    'fields' => array(
						array(
							'name' => 'oEmbed',
							'desc' => 'Enter a youtube, twitter, or instagram URL. Supports services listed at <a href="http://codex.wordpress.org/Embeds">http://codex.wordpress.org/Embeds</a>.',
							'id'   => $prefix . 'the_oembed',
							'type' => 'oembed',
						),
				    ),
				),
			)
		);
		
		/**
		 * Post & Portfolio Header Images
		 */
		$meta_boxes[] = array(
			'id' => 'post_header_metabox',
			'title' => __('Page Overrides', 'kwoon'),
			'object_types' => array('page', 'team', 'post', 'portfolio'), // post type
			'context' => 'normal',
			'priority' => 'low',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
					'name'         => __( 'Override Header?', 'kwoon' ),
					'desc'         => __( 'Header Layout is set in "appearance" -> "customise". To override this for this page only, use this control.', 'kwoon' ),
					'id'           => $prefix . 'header_override',
					'type'         => 'select',
					'options'      => $header_overrides,
					'std'          => 'none'
				)
			)
		);
		
		return $meta_boxes;
	}
	add_filter( 'cmb2_meta_boxes', 'ebor_custom_metaboxes' );
}